//
//  CardView.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/16.
//

import SwiftUI

struct CardView: View {

  // MARK: Internal

  var namespace: Namespace.ID

  var tokenImage: Card

  @Binding var selectedCard: Card!

  var body: some View {
    cardView()
      .onTapGesture {
        withAnimation(.spring(response: 0.4, dampingFraction: 0.7)) {
          selectedCard = tokenImage
        }
      }
  }


  // MARK: Private

  @ViewBuilder
  private func cardView() -> some View {
    ZStack {
      if tokenImage.id != selectedCard?.id {
        Image(tokenImage.imageString)
          .resizable()
          .aspectRatio(contentMode: .fill)
          .frame(width: 335, height: 409, alignment: .center)
          .clipShape(RoundedRectangle(cornerRadius: 23.0))
          .matchedGeometryEffect(id: "image\(tokenImage.id)", in: namespace)

        VStack(alignment: .leading) {
          Text(tokenImage.title)
          Text("Tier 1")
        }
        .font(.headline)
        .foregroundColor(.white)
        .frame(maxWidth: .infinity, maxHeight: .infinity, alignment: .topLeading)
        .padding(.all, 20)
        .matchedGeometryEffect(id: "text\(tokenImage.id)", in: namespace)
      } else {
        Image(tokenImage.imageString)
          .resizable()
          .aspectRatio(contentMode: .fill)
          .frame(width: 335, height: 409, alignment: .center)
          .clipShape(RoundedRectangle(cornerRadius: 23.0))
          .hidden()
      }
    }
    .frame(width: 335, height: 409, alignment: .center)
  }

}

#Preview {
  @Namespace var namespace
  return CardView(
    namespace: namespace,
    tokenImage: Card(id: 0, title: "醫翠絲", imageString: "Japan1"),
    selectedCard: .constant(Card(id: 0, title: "醫翠絲", imageString: "Japan1")))
}
