//
//  DashBoardButton.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/30.
//

import SwiftUI

struct DashboardButton: View {

  // MARK: Internal

  @State var title: String

  @State var number: String

  var model: ProfileDetailModel

  @State var longPressTap = false

  var body: some View {
    RoundedRectangle(cornerRadius: 15)
      .foregroundStyle(Color.lightGray)
      .frame(
        width: countWidth() / 2,
        height: countWidth() / 4)
      .overlay {
        textView()
      }
      .compositingGroup()
      .scaleEffect(longPressTap ? 0.95 : 1)
      .animation(.easeInOut(duration: 0.25), value: longPressTap)
      .onTapGesture(count: 1) {
        console.log("Tap Gesture")
        longPressTap = false
        model.dashboardTapped(title: title)
      }
      .simultaneousGesture(
        LongPressGesture(minimumDuration: 0.2)
          .onEnded { _ in
            console.log("LongPressGesture Gesture Started")
            longPressTap = true
          }
          .sequenced(
            before: TapGesture(count: 1)
              .onEnded {
                console.log("LongPressGesture Gesture Ended")
                longPressTap = false
                model.dashboardTapped(title: title)
              }))
      .simultaneousGesture(
        DragGesture()
          .onChanged { _ in
            longPressTap = false
          })
  }

  // MARK: Private

  @MainActor
  private func countWidth() -> CGFloat {
    UIScreen.main.bounds.width - .ideal(16) * 3
  }

  @MainActor
  @ViewBuilder
  private func textView() -> some View {
    VStack(alignment: .leading, spacing: 0) {
      HStack(spacing: 0) {
        Text("\(title)")
          .font(.notosans(size: 14).weight(.medium))
          .foregroundStyle(.gray)
        Spacer()
        Image("arrowCircleRight")
      }
      Spacer()
      Text("\(number)")
        .font(.notosans(size: 29).bold())
        .frame(height: 29)
    }
    .padding(14)
    .frame(
      width: countWidth() / 2,
      height: countWidth() / 4)
  }
}

#Preview {
  DashboardButton(title: "數位會員卡", number: "25", model: ProfileDetailModel())
}
