//
//  FolderView.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/19.
//

import SwiftUI

// MARK: - PhysicalMapView

struct PhysicalMapView: View {

  @Binding var isRetail: Bool

  var body: some View {
    ZStack(alignment: .top) {
      RightFolderView()
        .frame(width: .ideal(343), height: .ideal(205))
        .foregroundStyle(.thinMaterial)
        .onTapGesture {
          withAnimation(.easeInOut) {
            isRetail = true
          }
        }
      LeftFolderView()
        .frame(width: .ideal(340), height: .ideal(218))
        .foregroundStyle(.white)
      ZStack {
        Text("實體店面")
          .font(.notosans(size: 12).bold())
          .offset(x: CGFloat(-UIScreen.main.bounds.width / 4.5))
        Text("虛擬世界")
          .font(.notosans(size: 12))
          .foregroundStyle(.secondary)
          .offset(x: CGFloat(UIScreen.main.bounds.width / 4.5))
      }
      .font(.system(size: 13))
      .padding(.vertical, 10)
    }
    .compositingGroup()
    .shadow(color: .black.opacity(0.15), radius: 2.5, x: 1, y: 1)
  }

}

// MARK: - VirtualMapView

struct VirtualMapView: View {

  @Binding var isRetail: Bool

  var body: some View {
    ZStack(alignment: .top) {
      LeftFolderView()
        .frame(width: .ideal(330), height: .ideal(205))
        .foregroundStyle(.thinMaterial)
        .offset(y: CGFloat(5))
        .onTapGesture {
          withAnimation(.easeInOut) {
            isRetail = false
          }
        }
      RightFolderView()
        .frame(width: .ideal(343), height: .ideal(218))
        .foregroundStyle(.white)
      ZStack {
        Text("實體店面")
          .font(.notosans(size: 12))
          .foregroundStyle(.secondary)
          .offset(x: CGFloat(-UIScreen.main.bounds.width / 4.5))
        Text("虛擬世界")
          .font(.notosans(size: 12).bold())
          .offset(x: CGFloat(UIScreen.main.bounds.width / 4.5))
      }
      .font(.system(size: 13))
      .padding(.vertical, 10)
    }
    .compositingGroup()
    .shadow(color: .black.opacity(0.15), radius: 2.5, x: 1, y: 1)
  }

}

// MARK: - RightFolderView

struct RightFolderView: Shape {
  func path(in rect: CGRect) -> Path {
    var path = Path()
    let width = rect.size.width
    let height = rect.size.height
    path.move(to: CGPoint(x: 0.01133 * width, y: 0.9057 * height))
    path.addLine(to: CGPoint(x: 0.01133 * width, y: 0.23118 * height))
    path.addLine(to: CGPoint(x: 0.01133 * width, y: 0.23026 * height))
    path.addCurve(
      to: CGPoint(x: 0.05382 * width, y: 0.16447 * height),
      control1: CGPoint(x: 0.01133 * width, y: 0.19393 * height),
      control2: CGPoint(x: 0.03036 * width, y: 0.16447 * height))
    path.addLine(to: CGPoint(x: 0.43526 * width, y: 0.16447 * height))
    path.addCurve(
      to: CGPoint(x: 0.47246 * width, y: 0.13049 * height),
      control1: CGPoint(x: 0.45073 * width, y: 0.16447 * height),
      control2: CGPoint(x: 0.46498 * width, y: 0.15146 * height))
    path.addLine(to: CGPoint(x: 0.50063 * width, y: 0.05153 * height))
    path.addCurve(
      to: CGPoint(x: 0.53782 * width, y: 0.01754 * height),
      control1: CGPoint(x: 0.5081 * width, y: 0.03056 * height),
      control2: CGPoint(x: 0.52235 * width, y: 0.01754 * height))
    path.addLine(to: CGPoint(x: 0.93523 * width, y: 0.01754 * height))
    path.addCurve(
      to: CGPoint(x: 0.97773 * width, y: 0.08273 * height),
      control1: CGPoint(x: 0.95855 * width, y: 0.01754 * height),
      control2: CGPoint(x: 0.97751 * width, y: 0.04663 * height))
    path.addLine(to: CGPoint(x: 0.98261 * width, y: 0.9051 * height))
    path.addCurve(
      to: CGPoint(x: 0.94012 * width, y: 0.97149 * height),
      control1: CGPoint(x: 0.98282 * width, y: 0.94167 * height),
      control2: CGPoint(x: 0.96374 * width, y: 0.97149 * height))
    path.addLine(to: CGPoint(x: 0.05382 * width, y: 0.97149 * height))
    path.addCurve(
      to: CGPoint(x: 0.01133 * width, y: 0.9057 * height),
      control1: CGPoint(x: 0.03036 * width, y: 0.97149 * height),
      control2: CGPoint(x: 0.01133 * width, y: 0.94204 * height))
    path.closeSubpath()
    return path
  }
}

// MARK: - LeftFolderView

struct LeftFolderView: Shape {
  func path(in rect: CGRect) -> Path {
    var path = Path()
    let width = rect.size.width
    let height = rect.size.height
    path.move(to: CGPoint(x: 0, y: 0.93088 * height))
    path.addLine(to: CGPoint(x: 0, y: 0.1489 * height))
    path.addLine(to: CGPoint(x: 0, y: 0.06912 * height))
    path.addCurve(to: CGPoint(x: 0.04412 * width, y: 0), control1: CGPoint(x: 0, y: 0.03095 * height), control2: CGPoint(x: 0.01975 * width, y: 0))
    path.addLine(to: CGPoint(x: 0.43783 * width, y: 0))
    path.addCurve(
      to: CGPoint(x: 0.47846 * width, y: 0.04216 * height),
      control1: CGPoint(x: 0.45555 * width, y: 0),
      control2: CGPoint(x: 0.47155 * width, y: 0.0166 * height))
    path.addLine(to: CGPoint(x: 0.4957 * width, y: 0.10597 * height))
    path.addCurve(
      to: CGPoint(x: 0.53706 * width, y: 0.14812 * height),
      control1: CGPoint(x: 0.50272 * width, y: 0.13191 * height),
      control2: CGPoint(x: 0.51908 * width, y: 0.14859 * height))
    path.addLine(to: CGPoint(x: 0.95515 * width, y: 0.1372 * height))
    path.addCurve(
      to: CGPoint(x: width, y: 0.20632 * height),
      control1: CGPoint(x: 0.9798 * width, y: 0.13656 * height),
      control2: CGPoint(x: width, y: 0.16769 * height))
    path.addLine(to: CGPoint(x: width, y: 0.93088 * height))
    path.addCurve(
      to: CGPoint(x: 0.95588 * width, y: height),
      control1: CGPoint(x: width, y: 0.96905 * height),
      control2: CGPoint(x: 0.98025 * width, y: height))
    path.addLine(to: CGPoint(x: 0.04412 * width, y: height))
    path.addCurve(
      to: CGPoint(x: 0, y: 0.93088 * height),
      control1: CGPoint(x: 0.01975 * width, y: height),
      control2: CGPoint(x: 0, y: 0.96905 * height))
    path.closeSubpath()
    return path
  }
}

#Preview {
  PhysicalMapView(isRetail: .constant(false))
}

#Preview {
  VirtualMapView(isRetail: .constant(true))
}
