//
//  ListRowComponent.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/30.
//

import SwiftUI
import SwiftUIKit

struct ProfileListComponent: View {

  @State var icon: String

  @State var title: String

  var model: ProfileDetailModel

  @State var longPressTap = false

  var body: some View {
    ScrollViewGestureButton(
      releaseInsideAction: {
        model.listTapped(title: title)
      },
      longPressDelay: 0.2)
    { longPressTap in
      listLabel(longPressTap: longPressTap)
    }
  }

  @MainActor
  @ViewBuilder
  func listLabel(longPressTap: Bool) -> some View {
    VStack(spacing: 0) {
      HStack(spacing: 8) {
        Image(systemName: icon)
          .frame(width: 30, height: 30)
          .foregroundStyle(Color.black)
        VStack(alignment: .leading) {
          Spacer()
          HStack {
            Text("\(title)")
              .font(.notosans(size: 14))
              .fontWeight(.medium)
              .foregroundStyle(Color.black)
            Spacer()
            Image("chevronRight")
              .frame(width: 30, height: 30)
              .foregroundStyle(Color.midGray)
          }
          Spacer()
        }
        .frame(width: .ideal(291), height: .ideal(64))
        .contentShape(.rect)
      }
      .padding(.horizontal)
      .compositingGroup()
      .scaleEffect(longPressTap ? 0.95 : 1)
      .animation(.easeInOut(duration: 0.25), value: longPressTap)
      Rectangle()
        .stroke(Color.midGray, lineWidth: 0.5)
        .frame(width: .ideal(343), height: 0.5)
    }
  }

}

#Preview {
  ProfileListComponent(icon: "creditCard", title: "信用卡", model: ProfileDetailModel())
}
