//
//  SettingListComponent.swift
//  pomo
//
//  Created by Nick Liu on 2024/2/19.
//

import SwiftUI
import SwiftUIKit

struct SettingListComponent: View {

  // MARK: Internal

  @State var title: String

  var model: SettingDetailModel

  var isLast = false

  @State var longPressTap = false

  var body: some View {
    VStack(spacing: 0) {
      HStack(spacing: 8) {
        ScrollViewGestureButton(
          releaseInsideAction: {
            model.listTapped(title: title)
          },
          longPressDelay: 0.2)
        { longPressTap in
          listLabel(longPressTap: longPressTap)
        }
      }
      if !isLast {
        Rectangle()
          .stroke(Color.midGray, lineWidth: 0.5)
          .frame(width: .ideal(343), height: 0.5)
      }
    }
    .frame(width: .ideal(343))
  }

  // MARK: Private

  @MainActor
  private func listLabel(longPressTap: Bool) -> some View {
    var longPressTap = longPressTap
    if title == "電子郵件" {
      longPressTap = false
    }
    return VStack(alignment: .leading) {
      Spacer()
      HStack(spacing: 0) {
        titleView(title: title)
          .font(.notosans(size: 14))
          .fontWeight(.medium)
          .foregroundStyle(Color.black)
        Spacer()
        descriptionView(title: title)
          .font(.notosans(size: 14))
          .lineLimit(1)
          .truncationMode(.tail)
          .foregroundStyle(Color(hex: "#454545"))

        iconView(title: title)
          .frame(width: 35, height: 35)
          .foregroundStyle(Color.midGray)
      }
      .padding(.horizontal, 16)
      Spacer()
    }
    .frame(width: .ideal(343), height: .ideal(63))
    .contentShape(.rect)
    .padding(.horizontal)
    .compositingGroup()
    .scaleEffect(longPressTap ? 0.95 : 1)
    .animation(.easeInOut(duration: 0.25), value: longPressTap)
  }

  @ViewBuilder
  private func titleView(title: String) -> some View {
    switch title {
    case "刪除帳號":
      Text("\(title)")
        .foregroundStyle(Color.red)
    default:
      Text("\(title)")
    }
  }

  @ViewBuilder
  private func descriptionView(title: String) -> some View {
    switch title {
    case "姓名":
      Text("User")
    case "電子郵件":
      Text(model.user.email)
    case "手機號碼":
      Text("尚未綁定")
        .foregroundStyle(Color.red)
    case "錢包地址":
      Text(model.user.walletAddress)
    default:
      EmptyView()
    }
  }

  @ViewBuilder
  private func iconView(title: String) -> some View {
    switch title {
    case "錢包地址":
      Image("copy")
    case "電子郵件":
      EmptyView()
    case "登出", "刪除帳號":
      Image("share") // TODO: rename
    default:
      Image("chevronRight")
    }
  }
}

#Preview {
  SettingListComponent(title: "手機號碼", model: SettingDetailModel())
}
