//
//  Extension + UIKit.swift
//  pomo
//
//  Created by Nick Liu on 2024/2/1.
//

import UIKit

// When creating and using a custom navigation bar in SwiftUI, if you use .toolbar(.hidden) to deactivate the default navigation bar
// that is typically displayed in iOS, it will also disable the Swipe back gesture commonly used in iOS.
// To re-enable this gesture, you need to add some code to the UIKit’s UINavigationController like below.

extension UINavigationController: UIGestureRecognizerDelegate {

  // MARK: Open

  open override func viewDidLoad() {
    super.viewDidLoad()
    interactivePopGestureRecognizer?.delegate = self
  }

  // MARK: Public

  public func gestureRecognizerShouldBegin(_ gestureRecognizer: UIGestureRecognizer) -> Bool {
    viewControllers.count > 1
  }
}
