//
//  HomeDetailModel.swift
//  pomo
//
//  Created by Nick Liu on 2024/2/1.
//

import SwiftUI
import SwiftUINavigation

// MARK: - HomeDetailModel

class HomeDetailModel: ObservableObject {

  // MARK: Lifecycle

  init(destination: Destination? = nil, memberCards: [Card] = .mock, user: User = .initial) {
    self.destination = destination
    self.memberCards = memberCards
    self.user = user
  }

  // MARK: Internal

  enum Destination {
    case bindPhone
    case profile(ProfileDetailModel)
    case upgrade([Card])
  }

  @Published var destination: Destination?

  @Published var user: User

  var memberCards: [Card]

  func profileButtonTapped() {
    destination = .profile(ProfileDetailModel(memberCards: memberCards, user: user))
  }

  func upgradeButtonTapped() {
    destination = .upgrade(memberCards)
  }

  @MainActor
  func bindPhoneButtonTapped() async {
    print(1)
    try? await Task.sleep(for: .seconds(0.4))
    print(2)
    destination = .profile(ProfileDetailModel(destination: .setting(SettingDetailModel())))
    print(3)
  }

}

// MARK: Sendable

extension HomeDetailModel: @unchecked Sendable { }
