//
//  ContentView.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/16.
//

import SwiftUI
import SwiftUINavigation

// MARK: - HomeView

struct HomeView: View {

  @ObservedObject var model: HomeDetailModel

  var body: some View {
    NavigationStack {
      toolBarView()
        .navigationDestination(
          unwrapping: $model.destination,
          case: /HomeDetailModel.Destination.profile)
      { $model in
        ProfileView(model: model)
      }
      .sheet(unwrapping: $model.destination, case: /HomeDetailModel.Destination.bindPhone) { _ in
        BindPhoneView {
          Task {
            await model.bindPhoneButtonTapped()
          }
        }
        .sheetCornerRadius()
        .presentationDetents([.height(.ideal(415))])
        .presentationDragIndicator(.visible)
      }
    }
  }

  @MainActor
  @ViewBuilder
  private func toolBarView() -> some View {
    HStack {
      Image(systemName: "person.fill")
        .frame(width: 20, height: 20)
        .padding(10)
        .onTapGesture {
          model.profileButtonTapped()
        }
    }
    .padding(.horizontal, 10)
  }

}

#Preview {
  HomeView(model: HomeDetailModel())
}
