//
//  MembershipView.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/31.
//

import SwiftUI

struct MembershipsView: View {

  // MARK: Internal

  @ObservedObject var model: MemberDetailModel

  var body: some View {
    ScrollView(.vertical, showsIndicators: false) {
      VStack(spacing: 0) {
        Spacer(minLength: .ideal(90))
        ForEach(model.memberCards, id: \.self) { card in
          CardThumbnail(memberCard: card)
        }
      }
    }
    .frame(maxWidth: .infinity)
    .coordinateSpace(name: "scrollView")
    .overlay(alignment: .top) {
      headerView()
    }
    .overlay(alignment: .topLeading) {
      toolBarView()
    }
    .navigationBarBackButtonHidden()
  }

  // MARK: Private

  @State private var searchText = ""

  @Environment(\.dismiss) private var dismiss

  @State private var hasScrolledToTop = false

  @State private var scrollProgress: CGFloat = 0

  @MainActor
  @ViewBuilder
  private func headerView() -> some View {
    Rectangle()
      .foregroundStyle(.white.opacity(hasScrolledToTop ? 0.8 : 1))
      .background(.ultraThinMaterial.opacity(hasScrolledToTop ? 1 : 0))
      .ignoresSafeArea()
      .frame(width: UIScreen.main.bounds.width, height: .ideal(100))
      .overlay {
        VStack {
          Text("數位會員")
            .font(.notosans(size: 18).weight(.medium))
          SearchBar(searchText: $searchText)
          Spacer()
          Rectangle()
            .foregroundStyle(Color(hex: "#E6E6E6"))
            .frame(width: UIScreen.main.bounds.width, height: 0.5)
            .opacity(hasScrolledToTop ? 1 : 0)
        }
        .padding(.top, 8)
      }
  }

  @ViewBuilder
  private func toolBarView() -> some View {
    HStack {
      Button {
        dismiss()
      } label: {
        Image(systemName: "chevron.left")
      }
    }
    .padding(.horizontal, 10)
  }
}

#Preview {
  MembershipsView(model: MemberDetailModel(memberCards: []))
}
