//
//  ProfileViewModel.swift
//  pomo
//
//  Created by Nick Liu on 2024/2/1.
//

import SwiftUI
import SwiftUINavigation

// MARK: - ProfileDetailModel

class ProfileDetailModel: ObservableObject {

  // MARK: Lifecycle

  init(destination: Destination? = nil, memberCards: [Card] = .mock, user: User = .initial) {
    self.destination = destination
    self.memberCards = memberCards
    self.user = user
  }

  // MARK: Internal

  enum Destination {
    case member(MemberDetailModel)
    case setting(SettingDetailModel)
  }

  @Published var destination: Destination?

  @Published var memberCards: [Card]

  var user: User

  func dashboardTapped(title: String) {
    switch title {
    case "數位會員卡":
      destination = .member(MemberDetailModel(memberCards: memberCards))
    default:
      break
    }
  }

  func listTapped(title: String) {
    switch title {
    case "帳號設定":
      destination = .setting(SettingDetailModel(memberCards: memberCards, user: user))
    default:
      break
    }
  }

}

// MARK: Sendable

extension ProfileDetailModel: @unchecked Sendable { }
