//
//  ProfileView.swift
//  pomo
//
//  Created by Nick Liu on 2024/1/30.
//

import SwiftUI
import SwiftUINavigation

struct ProfileView: View {

  // MARK: Internal

  @ObservedObject var model: ProfileDetailModel

  @State var profileImage: Image? = Image("profilePicture")

  var profileList: [ProfileList] = .config

  var body: some View {
    VStack {
      ScrollView {
        VStack {
          Spacer(minLength: .ideal(77))
          HStack {
            profilePicView()
            accountInfoView()
            Spacer()
          }
          .padding(.horizontal)
          .padding(.bottom)
          dashboardView()
          listView()
        }
        Spacer(minLength: .ideal(30))
      }
      .navigationDestination(
        unwrapping: $model.destination,
        case: /ProfileDetailModel.Destination.setting)
      { $model in
        SettingView(model: model)
      }
      .navigationDestination(
        unwrapping: $model.destination,
        case: /ProfileDetailModel.Destination.member)
      { $model in
        MembershipsView(model: model)
      }
      .overlay(alignment: .topLeading) {
        toolBarView()
      }
    }
    .navigationBarBackButtonHidden()
  }

  // MARK: Private

  @Environment(\.dismiss) private var dismiss

  @MainActor
  @ViewBuilder
  private func profilePicView() -> some View {
    ZStack {
      Circle()
        .foregroundColor(.cyan)
      profileImage?
        .resizable()
        .aspectRatio(contentMode: .fit)
    }
    .clipShape(.circle)
    .frame(width: .ideal(60), height: .ideal(60))
  }

  @ViewBuilder
  private func accountInfoView() -> some View {
    VStack(alignment: .leading, spacing: 8) {
      Text("Jason Wang")
        .font(.notosans(size: 16).bold())
      HStack {
        Text("\(model.user.email)")
          .font(.notosans(size: 14))
          .foregroundColor(.gray)
        Image("verified")
      }
    }
  }

  @ViewBuilder
  private func dashboardView() -> some View {
    HStack {
      Spacer()
      DashboardButton(
        title: "數位會員卡",
        number: (model.memberCards.count).leadingZero(), model: model)
      Spacer()
      DashboardButton(title: "使用紀錄", number: 3.leadingZero(), model: model)
      Spacer()
    }
  }

  @ViewBuilder
  private func listView() -> some View {
    ForEach(profileList, id: \.self) { list in
      ProfileListComponent(icon: list.icon, title: list.title, model: model)
    }
  }

  @ViewBuilder
  private func toolBarView() -> some View {
    HStack {
      Button {
        dismiss()
      } label: {
        Image(systemName: "chevron.left")
      }
      Spacer()
    }
    .padding(.horizontal, 10)
  }

}

#Preview {
  ProfileView(model: ProfileDetailModel())
}
