//
//  SettingView.swift
//  pomo
//
//  Created by Nick Liu on 2024/2/17.
//

import SwiftUI

struct SettingView: View {

  @Environment(\.dismiss) private var dismiss

  var basicSettingList: [SettingList] = .basic

  var moreSettingList: [SettingList] = .more

  @ObservedObject var model: SettingDetailModel

  var body: some View {
    ScrollView(.vertical, showsIndicators: false) {
      VStack(spacing: 0) {
        Spacer(minLength: .ideal(77))
        Text("基本資訊")
          .padding(.horizontal, 16)
          .padding(.top, .ideal(26))
          .padding(.bottom, .ideal(14))
          .frame(width: .ideal(343), alignment: .leading)
          .font(.notosans(size: 14))
          .foregroundStyle(Color(hex: "#666666"))

        basicListView()

        Text("更多")
          .padding(.horizontal, 16)
          .padding(.top, .ideal(26))
          .padding(.bottom, .ideal(14))
          .frame(width: .ideal(343), alignment: .leading)
          .font(.notosans(size: 14))
          .foregroundStyle(Color(hex: "#666666"))
        moreListView()
      }
      .frame(width: .ideal(343))
    }
    .frame(maxWidth: .infinity) // fix the back button at the right place
    .overlay(alignment: .topLeading) {
      toolBarView()
    }
    .overlay(alignment: .top) {
      Text("帳號設定")
        .font(.notosans(size: 18).weight(.medium))
    }
    .navigationBarBackButtonHidden()
  }

  @MainActor
  @ViewBuilder
  private func basicListView() -> some View {
    ZStack {
      RoundedRectangle(cornerRadius: 22)
        .frame(width: .ideal(343), height: .ideal(252))
        .foregroundStyle(Color(hex: "#e6e6e6"))
      VStack(spacing: 0) {
        ForEach(basicSettingList.indices, id: \.self) { index in
          let isLast = index == basicSettingList.count - 1
          SettingListComponent(title: basicSettingList[index].title, model: model, isLast: isLast)
        }
      }
    }
  }

  @MainActor
  @ViewBuilder
  private func moreListView() -> some View {
    ZStack {
      RoundedRectangle(cornerRadius: 22)
        .frame(width: .ideal(343), height: .ideal(126))
        .foregroundStyle(Color(hex: "#e6e6e6"))
      VStack(spacing: 0) {
        ForEach(moreSettingList.indices, id: \.self) { index in
          let isLast = index == moreSettingList.count - 1
          SettingListComponent(title: moreSettingList[index].title, model: model, isLast: isLast)
        }
      }
    }
  }

  @ViewBuilder
  private func toolBarView() -> some View {
    HStack {
      Button {
        dismiss()
      } label: {
        Image(systemName: "chevron.left")
      }
      Spacer()
    }
    .padding(.horizontal, 10)
  }

}

#Preview {
  SettingView(model: SettingDetailModel())
}
